==> zego_uikit_prebuilt_call-4.5.0.tar.gz: lib/src/inner_text.dart <==
/// Control the text on the UI.
/// Modify the values of the corresponding properties to modify the text on the UI.
/// You can also change it to other languages.
/// This class is used for the ZegoUIKitPrebuiltCallConfig.innerText property.
class ZegoUIKitPrebuiltCallInnerText {
  /// The title of the audio effects dialog.
  /// The **default value** is *"Audio effects"*.
  String audioEffectTitle;

  /// The title of the reverb category.
  /// The **default value** is *"Reverb"*.
  String audioEffectReverbTitle;

  /// The title of the voice changing category.
  /// The **default value** is *"Voice changing"*.
  String audioEffectVoiceChangingTitle;

  /// Voice changing effect: None
  String voiceChangerNoneTitle;

  /// Voice changing effect: Little Boy
  String voiceChangerLittleBoyTitle;

  /// Voice changing effect: Little Girl
  String voiceChangerLittleGirlTitle;

  /// Voice changing effect: Deep
  String voiceChangerDeepTitle;

  /// Voice changing effect: Crystal-clear
  String voiceChangerCrystalClearTitle;

  /// Voice changing effect: Robot
  String voiceChangerRobotTitle;

  /// Voice changing effect: Ethereal
  String voiceChangerEtherealTitle;

  /// Voice changing effect：Female
  String voiceChangerFemaleTitle;

  /// Voice changing effect：Male
  String voiceChangerMaleTitle;

  /// Voice changing effect：Optimus Prime
  String voiceChangerOptimusPrimeTitle;

  /// Voice changing effect：C Major
  String voiceChangerCMajorTitle;

  /// Voice changing effect：A Major
  String voiceChangerAMajorTitle;

  /// Voice changing effect：Harmonic minor
  String voiceChangerHarmonicMinorTitle;

  /// Reverb effect：None
  String reverbTypeNoneTitle;

  /// Reverb effect: Karaoke
  String reverbTypeKTVTitle;

  /// Reverb effect：Hall
  String reverbTypeHallTitle;

  /// Reverb effect：Concert
  String reverbTypeConcertTitle;

  /// Reverb effect：Rock
  String reverbTypeRockTitle;

  /// Reverb effect：Small room
  String reverbTypeSmallRoomTitle;

  /// Reverb effect：Large room
  String reverbTypeLargeRoomTitle;

  /// Reverb effect：Valley
  String reverbTypeValleyTitle;

  /// Reverb effect：Recording studio
  String reverbTypeRecordingStudioTitle;

  /// Reverb effect：Basement
  String reverbTypeBasementTitle;

  /// Reverb effect：Pop
  String reverbTypePopularTitle;

  /// Reverb effect：Gramophone
  String reverbTypeGramophoneTitle;

  ZegoUIKitPrebuiltCallInnerText({
    String? audioEffectTitle,
    String? audioEffectReverbTitle,
    String? audioEffectVoiceChangingTitle,
    String? voiceChangerNoneTitle,
    String? voiceChangerLittleBoyTitle,
    String? voiceChangerLittleGirlTitle,
    String? voiceChangerDeepTitle,
    String? voiceChangerCrystalClearTitle,
    String? voiceChangerRobotTitle,
    String? voiceChangerEtherealTitle,
    String? voiceChangerFemaleTitle,
    String? voiceChangerMaleTitle,
    String? voiceChangerOptimusPrimeTitle,
    String? voiceChangerCMajorTitle,
    String? voiceChangerAMajorTitle,
    String? voiceChangerHarmonicMinorTitle,
    String? reverbTypeNoneTitle,
    String? reverbTypeKTVTitle,
    String? reverbTypeHallTitle,
    String? reverbTypeConcertTitle,
    String? reverbTypeRockTitle,
    String? reverbTypeSmallRoomTitle,
    String? reverbTypeLargeRoomTitle,
    String? reverbTypeValleyTitle,
    String? reverbTypeRecordingStudioTitle,
    String? reverbTypeBasementTitle,
    String? reverbTypePopularTitle,
    String? reverbTypeGramophoneTitle,
  })  : audioEffectTitle = audioEffectTitle ?? 'Audio effects',
        audioEffectReverbTitle = audioEffectReverbTitle ?? 'Reverb',
        audioEffectVoiceChangingTitle = audioEffectVoiceChangingTitle ?? 'Voice changing',
        voiceChangerNoneTitle = voiceChangerNoneTitle ?? 'None',
        voiceChangerLittleBoyTitle = voiceChangerLittleBoyTitle ?? 'Little boy',
        voiceChangerLittleGirlTitle = voiceChangerLittleGirlTitle ?? 'Little girl',
        voiceChangerDeepTitle = voiceChangerDeepTitle ?? 'Deep',
        voiceChangerCrystalClearTitle = voiceChangerCrystalClearTitle ?? 'Crystal-clear',
        voiceChangerRobotTitle = voiceChangerRobotTitle ?? 'Robot',
        voiceChangerEtherealTitle = voiceChangerEtherealTitle ?? 'Ethereal',
        voiceChangerFemaleTitle = voiceChangerFemaleTitle ?? 'Female',
        voiceChangerMaleTitle = voiceChangerMaleTitle ?? 'Male',
        voiceChangerOptimusPrimeTitle = voiceChangerOptimusPrimeTitle ?? 'Optimus Prime',
        voiceChangerCMajorTitle = voiceChangerCMajorTitle ?? 'C major',
        voiceChangerAMajorTitle = voiceChangerAMajorTitle ?? 'A major',
        voiceChangerHarmonicMinorTitle = voiceChangerHarmonicMinorTitle ?? 'Harmonic minor',
        reverbTypeNoneTitle = reverbTypeNoneTitle ?? 'None',
        reverbTypeKTVTitle = reverbTypeKTVTitle ?? 'Karaoke',
        reverbTypeHallTitle = reverbTypeHallTitle ?? 'Hall',
        reverbTypeConcertTitle = reverbTypeConcertTitle ?? 'Concert',
        reverbTypeRockTitle = reverbTypeRockTitle ?? 'Rock',
        reverbTypeSmallRoomTitle = reverbTypeSmallRoomTitle ?? 'Small room',
        reverbTypeLargeRoomTitle = reverbTypeLargeRoomTitle ?? 'Large room',
        reverbTypeValleyTitle = reverbTypeValleyTitle ?? 'Valley',
        reverbTypeRecordingStudioTitle = reverbTypeRecordingStudioTitle ?? 'Recording studio',
        reverbTypeBasementTitle = reverbTypeBasementTitle ?? 'Basement',
        reverbTypePopularTitle = reverbTypePopularTitle ?? 'Pop',
        reverbTypeGramophoneTitle = reverbTypeGramophoneTitle ?? 'Gramophone';
}

==> zego_uikit_prebuilt_call-4.8.5.tar.gz: lib/src/inner_text.dart <==
/// Control the text on the UI.
/// Modify the values of the corresponding properties to modify the text on the UI.
/// You can also change it to other languages.
/// This class is used for the ZegoUIKitPrebuiltCallConfig.innerText property.
class ZegoUIKitPrebuiltCallInnerText {
  /// The title of the audio effects dialog.
  /// The **default value** is *"Audio effects"*.
  String audioEffectTitle;

  /// The title of the reverb category.
  /// The **default value** is *"Reverb"*.
  String audioEffectReverbTitle;

  /// The title of the voice changing category.
  /// The **default value** is *"Voice changing"*.
  String audioEffectVoiceChangingTitle;

  /// Voice changing effect: None
  String voiceChangerNoneTitle;

  /// Voice changing effect: Little Boy
  String voiceChangerLittleBoyTitle;

  /// Voice changing effect: Little Girl
  String voiceChangerLittleGirlTitle;

  /// Voice changing effect: Deep
  String voiceChangerDeepTitle;

  /// Voice changing effect: Crystal-clear
  String voiceChangerCrystalClearTitle;

  /// Voice changing effect: Robot
  String voiceChangerRobotTitle;

  /// Voice changing effect: Ethereal
  String voiceChangerEtherealTitle;

  /// Voice changing effect：Female
  String voiceChangerFemaleTitle;

  /// Voice changing effect：Male
  String voiceChangerMaleTitle;

  /// Voice changing effect：Optimus Prime
  String voiceChangerOptimusPrimeTitle;

  /// Voice changing effect：C Major
  String voiceChangerCMajorTitle;

  /// Voice changing effect：A Major
  String voiceChangerAMajorTitle;

  /// Voice changing effect：Harmonic minor
  String voiceChangerHarmonicMinorTitle;

  /// Reverb effect：None
  String reverbTypeNoneTitle;

  /// Reverb effect: Karaoke
  String reverbTypeKTVTitle;

  /// Reverb effect：Hall
  String reverbTypeHallTitle;

  /// Reverb effect：Concert
  String reverbTypeConcertTitle;

  /// Reverb effect：Rock
  String reverbTypeRockTitle;

  /// Reverb effect：Small room
  String reverbTypeSmallRoomTitle;

  /// Reverb effect：Large room
  String reverbTypeLargeRoomTitle;

  /// Reverb effect：Valley
  String reverbTypeValleyTitle;

  /// Reverb effect：Recording studio
  String reverbTypeRecordingStudioTitle;

  /// Reverb effect：Basement
  String reverbTypeBasementTitle;

  /// Reverb effect：Pop
  String reverbTypePopularTitle;

  /// Reverb effect：Gramophone
  String reverbTypeGramophoneTitle;

  ZegoUIKitPrebuiltCallInnerText({
    String? audioEffectTitle,
    String? audioEffectReverbTitle,
    String? audioEffectVoiceChangingTitle,
    String? voiceChangerNoneTitle,
    String? voiceChangerLittleBoyTitle,
    String? voiceChangerLittleGirlTitle,
    String? voiceChangerDeepTitle,
    String? voiceChangerCrystalClearTitle,
    String? voiceChangerRobotTitle,
    String? voiceChangerEtherealTitle,
    String? voiceChangerFemaleTitle,
    String? voiceChangerMaleTitle,
    String? voiceChangerOptimusPrimeTitle,
    String? voiceChangerCMajorTitle,
    String? voiceChangerAMajorTitle,
    String? voiceChangerHarmonicMinorTitle,
    String? reverbTypeNoneTitle,
    String? reverbTypeKTVTitle,
    String? reverbTypeHallTitle,
    String? reverbTypeConcertTitle,
    String? reverbTypeRockTitle,
    String? reverbTypeSmallRoomTitle,
    String? reverbTypeLargeRoomTitle,
    String? reverbTypeValleyTitle,
    String? reverbTypeRecordingStudioTitle,
    String? reverbTypeBasementTitle,
    String? reverbTypePopularTitle,
    String? reverbTypeGramophoneTitle,
  })  : audioEffectTitle = audioEffectTitle ?? 'Audio effects',
        audioEffectReverbTitle = audioEffectReverbTitle ?? 'Reverb',
        audioEffectVoiceChangingTitle =
            audioEffectVoiceChangingTitle ?? 'Voice changing',
        voiceChangerNoneTitle = voiceChangerNoneTitle ?? 'None',
        voiceChangerLittleBoyTitle = voiceChangerLittleBoyTitle ?? 'Little boy',
        voiceChangerLittleGirlTitle =
            voiceChangerLittleGirlTitle ?? 'Little girl',
        voiceChangerDeepTitle = voiceChangerDeepTitle ?? 'Deep',
        voiceChangerCrystalClearTitle =
            voiceChangerCrystalClearTitle ?? 'Crystal-clear',
        voiceChangerRobotTitle = voiceChangerRobotTitle ?? 'Robot',
        voiceChangerEtherealTitle = voiceChangerEtherealTitle ?? 'Ethereal',
        voiceChangerFemaleTitle = voiceChangerFemaleTitle ?? 'Female',
        voiceChangerMaleTitle = voiceChangerMaleTitle ?? 'Male',
        voiceChangerOptimusPrimeTitle =
            voiceChangerOptimusPrimeTitle ?? 'Optimus Prime',
        voiceChangerCMajorTitle = voiceChangerCMajorTitle ?? 'C major',
        voiceChangerAMajorTitle = voiceChangerAMajorTitle ?? 'A major',
        voiceChangerHarmonicMinorTitle =
            voiceChangerHarmonicMinorTitle ?? 'Harmonic minor',
        reverbTypeNoneTitle = reverbTypeNoneTitle ?? 'None',
        reverbTypeKTVTitle = reverbTypeKTVTitle ?? 'Karaoke',
        reverbTypeHallTitle = reverbTypeHallTitle ?? 'Hall',
        reverbTypeConcertTitle = reverbTypeConcertTitle ?? 'Concert',
        reverbTypeRockTitle = reverbTypeRockTitle ?? 'Rock',
        reverbTypeSmallRoomTitle = reverbTypeSmallRoomTitle ?? 'Small room',
        reverbTypeLargeRoomTitle = reverbTypeLargeRoomTitle ?? 'Large room',
        reverbTypeValleyTitle = reverbTypeValleyTitle ?? 'Valley',
        reverbTypeRecordingStudioTitle =
            reverbTypeRecordingStudioTitle ?? 'Recording studio',
        reverbTypeBasementTitle = reverbTypeBasementTitle ?? 'Basement',
        reverbTypePopularTitle = reverbTypePopularTitle ?? 'Pop',
        reverbTypeGramophoneTitle = reverbTypeGramophoneTitle ?? 'Gramophone';
}
